Copy one of the the calibration curves into memory.
copyCalibrationCurve(cc = 1, postbomb = FALSE)Calibration curve for 14C dates: cc=1 for IntCal20 (northern hemisphere terrestrial), cc=2 for Marine20 (marine),
cc=3 for SHCal20 (southern hemisphere terrestrial).
Use postbomb=TRUE to get a postbomb calibration curve (default postbbomb=FALSE).
The calibration curve (invisible).
Copy the radiocarbon calibration curve defined by cc into memory.