Produce a plot of the 210Pb data and their depths
draw.pbmeasured(
set = get("info"),
rotate.axes = FALSE,
rev.d = FALSE,
rev.age = FALSE,
pb.lim = c(),
age.lim = c(),
d.lim = c(),
d.lab = c(),
pb.lab = c(),
pbmeasured.col = "blue",
pb.log = FALSE,
supp.col = "red"
)Detailed information of the current run, stored within this session's memory as variable info.
The default of plotting age on the horizontal axis and event probability on the vertical one can be changed with rotate.axes=TRUE.
The direction of the depth axis can be reversed from the default (rev.d=TRUE).
The direction of the calendar age axis can be reversed from the default (rev.age=TRUE)
Minimum and maximum of the 210Pb axis ranges, calculated automatically by default (pb.lim=c()).
Minimum and maximum of the age ranges to be used to plot 210Pb values. Calculated automatically by default (age.lim=c()).
Minimum and maximum depths to plot; calculated automatically by default (d.lim=c()).
The labels for the depth axis. Default d.lab="Depth (cm)".
The label for the 210Pb axis (default pb.lab="210Pb (Bq/kg)" or "210Pb (dpm/g)").
The label for the measured 210Pb data. pbmeasured.col="blue".
Use a log scale for the 210Pb-axis (default pb.log=FALSE).
Colour of the supported 210Pb data. Defaults to red: supp.col="red".
A plot of the measured 210Pb values
This function is generally called internally to produce the age-depth graph. It can be used to produce custom-built graphs.